@@ -7,9 +7,11 @@ from . import kmeans
 from . import kernels
 
 from .PQ import PQ
+from .MPQ import MPQ
 from .SQ import SQ
 from .IVFPQBase import IVFPQBase
 from .IVFPQTopk import IVFPQTopk
 
 from .IVFPQ import IVFPQ
 from .IVFPQR import IVFPQR
+from .IVFMPQ import IVFMPQ
